<?php
/**
 * Feminine Style Lite Theme Customizer
 *
 * @package Feminine Style Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function feminine_style_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-changer.php' );

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial(
		'blogname',
		array(
			'selector'        => '.site-title a',
			'render_callback' => 'feminine_style_lite_customize_partial_blogname',
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'blogdescription',
		array(
			'selector'        => '.site-description',
			'render_callback' => 'feminine_style_lite_customize_partial_blogdescription',
		)
	);

	//add home page setting pannel
	$wp_customize->add_panel( 'feminine_style_lite_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'Theme Settings', 'feminine-style-lite' ),
	) );

    $feminine_style_lite_font_array= array(
        '' =>'No Fonts',
        'Abril Fatface' => 'Abril Fatface',
        'Acme' =>'Acme', 
        'Anton' => 'Anton', 
        'Architects Daughter' =>'Architects Daughter',
        'Arimo' => 'Arimo', 
        'Arsenal' =>'Arsenal',
        'Arvo' =>'Arvo',
        'Alegreya' =>'Alegreya',
        'Alfa Slab One' =>'Alfa Slab One',
        'Averia Serif Libre' =>'Averia Serif Libre', 
        'Bangers' =>'Bangers', 
        'Boogaloo' =>'Boogaloo', 
        'Bad Script' =>'Bad Script',
        'Bitter' =>'Bitter', 
        'Bree Serif' =>'Bree Serif', 
        'BenchNine' =>'BenchNine',
        'Cabin' =>'Cabin',
        'Cardo' =>'Cardo', 
        'Courgette' =>'Courgette', 
        'Cherry Swash' =>'Cherry Swash',
        'Cormorant Garamond' =>'Cormorant Garamond', 
        'Crimson Text' =>'Crimson Text',
        'Cuprum' =>'Cuprum', 
        'Cookie' =>'Cookie',
        'Chewy' =>'Chewy',
        'Days One' =>'Days One',
        'Dosis' =>'Dosis',
        'Droid Sans' =>'Droid Sans', 
        'Economica' =>'Economica', 
        'Fredoka One' =>'Fredoka One',
        'Fjalla One' =>'Fjalla One',
        'Francois One' =>'Francois One', 
        'Frank Ruhl Libre' => 'Frank Ruhl Libre', 
        'Gloria Hallelujah' =>'Gloria Hallelujah',
        'Great Vibes' =>'Great Vibes', 
        'Handlee' =>'Handlee', 
        'Hammersmith One' =>'Hammersmith One',
        'Inconsolata' =>'Inconsolata',
        'Indie Flower' =>'Indie Flower', 
        'IM Fell English SC' =>'IM Fell English SC',
        'Julius Sans One' =>'Julius Sans One',
        'Josefin Slab' =>'Josefin Slab',
        'Josefin Sans' =>'Josefin Sans',
        'Kanit' =>'Kanit',
        'Lobster' =>'Lobster',
        'Lato' => 'Lato',
        'Lora' =>'Lora', 
        'Libre Baskerville' =>'Libre Baskerville',
        'Lobster Two' => 'Lobster Two',
        'Merriweather' =>'Merriweather',
        'Monda' =>'Monda',
        'Montserrat' =>'Montserrat',
        'Muli' =>'Muli',
        'Marck Script' =>'Marck Script',
        'Noto Serif' =>'Noto Serif',
        'Open Sans' =>'Open Sans',
        'Overpass' => 'Overpass', 
        'Overpass Mono' =>'Overpass Mono',
        'Oxygen' =>'Oxygen',
        'Orbitron' =>'Orbitron',
        'Patua One' =>'Patua One',
        'Pacifico' =>'Pacifico',
        'Padauk' =>'Padauk',
        'Playball' =>'Playball',
        'Playfair Display' =>'Playfair Display',
        'PT Sans' =>'PT Sans',
        'Philosopher' =>'Philosopher',
        'Permanent Marker' =>'Permanent Marker',
        'Poiret One' =>'Poiret One',
        'Quicksand' =>'Quicksand',
        'Quattrocento Sans' =>'Quattrocento Sans',
        'Raleway' =>'Raleway',
        'Rubik' =>'Rubik',
        'Rokkitt' =>'Rokkitt',
        'Russo One' => 'Russo One', 
        'Righteous' =>'Righteous', 
        'Slabo' =>'Slabo', 
        'Source Sans Pro' =>'Source Sans Pro',
        'Shadows Into Light Two' =>'Shadows Into Light Two',
        'Shadows Into Light' =>  'Shadows Into Light',
        'Sacramento' =>'Sacramento',
        'Shrikhand' =>'Shrikhand',
        'Tangerine' => 'Tangerine',
        'Ubuntu' =>'Ubuntu',
        'VT323' =>'VT323',
        'Varela Round' =>'Varela Round',
        'Vampiro One' =>'Vampiro One',
        'Vollkorn' => 'Vollkorn',
        'Volkhov' =>'Volkhov',
        'Kavoon' =>'Kavoon',
        'Yanone Kaffeesatz' =>'Yanone Kaffeesatz'
    );

	//Color / Font Pallete
	$wp_customize->add_section( 'feminine_style_lite_typography', array(
    	'title'      => __( 'Color / Font Pallete', 'feminine-style-lite' ),
		'priority'   => 30,
		'panel' => 'feminine_style_lite_panel_id'
	) );
	
	// This is Paragraph Color picker setting
	$wp_customize->add_setting( 'feminine_style_lite_paragraph_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_paragraph_color', array(
		'label' => __('Paragraph Color', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_typography',
		'settings' => 'feminine_style_lite_paragraph_color',
	)));

	//This is Paragraph FontFamily picker setting
	$wp_customize->add_setting('feminine_style_lite_paragraph_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control(
	    'feminine_style_lite_paragraph_font_family', array(
	    'section'  => 'feminine_style_lite_typography',
	    'label'    => __( 'Paragraph Fonts','feminine-style-lite'),
	    'type'     => 'select',
	    'choices'  => $feminine_style_lite_font_array,
	));

	$wp_customize->add_setting('feminine_style_lite_paragraph_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('feminine_style_lite_paragraph_font_size',array(
		'label'	=> __('Paragraph Font Size','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_typography',
		'setting'	=> 'feminine_style_lite_paragraph_font_size',
		'type'	=> 'text'
	));

	// This is "a" Tag Color picker setting
	$wp_customize->add_setting( 'feminine_style_lite_atag_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_atag_color', array(
		'label' => __('"a" Tag Color', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_typography',
		'settings' => 'feminine_style_lite_atag_color',
	)));

	//This is "a" Tag FontFamily picker setting
	$wp_customize->add_setting('feminine_style_lite_atag_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control(
	    'feminine_style_lite_atag_font_family', array(
	    'section'  => 'feminine_style_lite_typography',
	    'label'    => __( '"a" Tag Fonts','feminine-style-lite'),
	    'type'     => 'select',
	    'choices'  => $feminine_style_lite_font_array,
	));

	// This is "a" Tag Color picker setting
	$wp_customize->add_setting( 'feminine_style_lite_li_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_li_color', array(
		'label' => __('"li" Tag Color', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_typography',
		'settings' => 'feminine_style_lite_li_color',
	)));

	//This is "li" Tag FontFamily picker setting
	$wp_customize->add_setting('feminine_style_lite_li_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control(
	    'feminine_style_lite_li_font_family', array(
	    'section'  => 'feminine_style_lite_typography',
	    'label'    => __( '"li" Tag Fonts','feminine-style-lite'),
	    'type'     => 'select',
	    'choices'  => $feminine_style_lite_font_array,
	));

	// This is H1 Color picker setting
	$wp_customize->add_setting( 'feminine_style_lite_h1_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_h1_color', array(
		'label' => __('h1 Color', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_typography',
		'settings' => 'feminine_style_lite_h1_color',
	)));

	//This is H1 FontFamily picker setting
	$wp_customize->add_setting('feminine_style_lite_h1_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control(
	    'feminine_style_lite_h1_font_family', array(
	    'section'  => 'feminine_style_lite_typography',
	    'label'    => __( 'h1 Fonts','feminine-style-lite'),
	    'type'     => 'select',
	    'choices'  => $feminine_style_lite_font_array,
	));

	//This is H1 FontSize setting
	$wp_customize->add_setting('feminine_style_lite_h1_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('feminine_style_lite_h1_font_size',array(
		'label'	=> __('h1 Font Size','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_typography',
		'setting'	=> 'feminine_style_lite_h1_font_size',
		'type'	=> 'text'
	));

	// This is H2 Color picker setting
	$wp_customize->add_setting( 'feminine_style_lite_h2_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_h2_color', array(
		'label' => __('h2 Color', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_typography',
		'settings' => 'feminine_style_lite_h2_color',
	)));

	//This is H2 FontFamily picker setting
	$wp_customize->add_setting('feminine_style_lite_h2_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control(
	    'feminine_style_lite_h2_font_family', array(
	    'section'  => 'feminine_style_lite_typography',
	    'label'    => __( 'h2 Fonts','feminine-style-lite'),
	    'type'     => 'select',
	    'choices'  => $feminine_style_lite_font_array,
	));

	//This is H2 FontSize setting
	$wp_customize->add_setting('feminine_style_lite_h2_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('feminine_style_lite_h2_font_size',array(
		'label'	=> __('h2 Font Size','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_typography',
		'setting'	=> 'feminine_style_lite_h2_font_size',
		'type'	=> 'text'
	));

	// This is H3 Color picker setting
	$wp_customize->add_setting( 'feminine_style_lite_h3_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_h3_color', array(
		'label' => __('h3 Color', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_typography',
		'settings' => 'feminine_style_lite_h3_color',
	)));

	//This is H3 FontFamily picker setting
	$wp_customize->add_setting('feminine_style_lite_h3_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control(
	    'feminine_style_lite_h3_font_family', array(
	    'section'  => 'feminine_style_lite_typography',
	    'label'    => __( 'h3 Fonts','feminine-style-lite'),
	    'type'     => 'select',
	    'choices'  => $feminine_style_lite_font_array,
	));

	//This is H3 FontSize setting
	$wp_customize->add_setting('feminine_style_lite_h3_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('feminine_style_lite_h3_font_size',array(
		'label'	=> __('h3 Font Size','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_typography',
		'setting'	=> 'feminine_style_lite_h3_font_size',
		'type'	=> 'text'
	));

	// This is H4 Color picker setting
	$wp_customize->add_setting( 'feminine_style_lite_h4_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_h4_color', array(
		'label' => __('h4 Color', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_typography',
		'settings' => 'feminine_style_lite_h4_color',
	)));

	//This is H4 FontFamily picker setting
	$wp_customize->add_setting('feminine_style_lite_h4_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control(
	    'feminine_style_lite_h4_font_family', array(
	    'section'  => 'feminine_style_lite_typography',
	    'label'    => __( 'h4 Fonts','feminine-style-lite'),
	    'type'     => 'select',
	    'choices'  => $feminine_style_lite_font_array,
	));

	//This is H4 FontSize setting
	$wp_customize->add_setting('feminine_style_lite_h4_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('feminine_style_lite_h4_font_size',array(
		'label'	=> __('h4 Font Size','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_typography',
		'setting'	=> 'feminine_style_lite_h4_font_size',
		'type'	=> 'text'
	));

	// This is H5 Color picker setting
	$wp_customize->add_setting( 'feminine_style_lite_h5_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_h5_color', array(
		'label' => __('h5 Color', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_typography',
		'settings' => 'feminine_style_lite_h5_color',
	)));

	//This is H5 FontFamily picker setting
	$wp_customize->add_setting('feminine_style_lite_h5_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control(
	    'feminine_style_lite_h5_font_family', array(
	    'section'  => 'feminine_style_lite_typography',
	    'label'    => __( 'h5 Fonts','feminine-style-lite'),
	    'type'     => 'select',
	    'choices'  => $feminine_style_lite_font_array,
	));

	//This is H5 FontSize setting
	$wp_customize->add_setting('feminine_style_lite_h5_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('feminine_style_lite_h5_font_size',array(
		'label'	=> __('h5 Font Size','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_typography',
		'setting'	=> 'feminine_style_lite_h5_font_size',
		'type'	=> 'text'
	));

	// This is H6 Color picker setting
	$wp_customize->add_setting( 'feminine_style_lite_h6_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_h6_color', array(
		'label' => __('h6 Color', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_typography',
		'settings' => 'feminine_style_lite_h6_color',
	)));

	//This is H6 FontFamily picker setting
	$wp_customize->add_setting('feminine_style_lite_h6_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control(
	    'feminine_style_lite_h6_font_family', array(
	    'section'  => 'feminine_style_lite_typography',
	    'label'    => __( 'h6 Fonts','feminine-style-lite'),
	    'type'     => 'select',
	    'choices'  => $feminine_style_lite_font_array,
	));

	//This is H6 FontSize setting
	$wp_customize->add_setting('feminine_style_lite_h6_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('feminine_style_lite_h6_font_size',array(
		'label'	=> __('h6 Font Size','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_typography',
		'setting'	=> 'feminine_style_lite_h6_font_size',
		'type'	=> 'text'
	));

	//Layouts
	$wp_customize->add_section( 'feminine_style_lite_left_right', array(
    	'title'      => __( 'Theme Layout Settings', 'feminine-style-lite' ),
		'priority'   => 30,
		'panel' => 'feminine_style_lite_panel_id'
	) );

	$wp_customize->add_setting('feminine_style_lite_width_options',array(
        'default' => 'Full Layout',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control('feminine_style_lite_width_options',array(
        'type' => 'select',
        'label' => __('Select Site Layout','feminine-style-lite'),
        'section' => 'feminine_style_lite_left_right',
        'choices' => array(
            'Full Layout' => __('Full Layout','feminine-style-lite'),
            'Contained Layout' => __('Contained Layout','feminine-style-lite'),
            'Boxed Layout' => __('Boxed Layout','feminine-style-lite'),
        ),
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('feminine_style_lite_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	) );
	$wp_customize->add_control('feminine_style_lite_theme_options', array(
        'type' => 'radio',
        'label' => __('Sidebar Layout','feminine-style-lite'),
        'section' => 'feminine_style_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','feminine-style-lite'),
            'Right Sidebar' => __('Right Sidebar','feminine-style-lite'),
            'One Column' => __('One Column','feminine-style-lite'),
            'Three Columns' => __('Three Columns','feminine-style-lite'),
            'Four Columns' => __('Four Columns','feminine-style-lite'),
            'Grid Layout' => __('Grid Layout','feminine-style-lite')
        ),
    ));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('feminine_style_lite_single_post_sidebar',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	) );
	$wp_customize->add_control('feminine_style_lite_single_post_sidebar', array(
        'type' => 'radio',
        'label' => __('Single Post Sidebar Layout','feminine-style-lite'),
        'section' => 'feminine_style_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','feminine-style-lite'),
            'Right Sidebar' => __('Right Sidebar','feminine-style-lite'),
            'One Column' => __('One Column','feminine-style-lite'),
        ),
    ));

    //Topbar
	$wp_customize->add_section('feminine_style_lite_topbar',array(
		'title'	=> __('Topbar','feminine-style-lite'),
		'priority'	=> null,
		'panel' => 'feminine_style_lite_panel_id',
	));

	$wp_customize->add_setting( 'feminine_style_lite_show_topbar',array(
		'default' => false,
      	'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ) );
    $wp_customize->add_control('feminine_style_lite_show_topbar',array(
    	'type' => 'checkbox',
        'label' => __( 'Show/Hide Topbar','feminine-style-lite' ),
        'section' => 'feminine_style_lite_topbar'
    ));

    $wp_customize->add_setting('feminine_style_lite_topbar_email',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));	
	$wp_customize->add_control('feminine_style_lite_topbar_email',array(
		'label'	=> __('Add Email Address','feminine-style-lite'),
		'section' => 'feminine_style_lite_topbar',
		'type'	=> 'text'
	));

    $wp_customize->add_setting('feminine_style_lite_subscribe_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('feminine_style_lite_subscribe_text',array(
		'label'	=> __('Add Subscribe Text','feminine-style-lite'),
		'section' => 'feminine_style_lite_topbar',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('feminine_style_lite_facebook_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('feminine_style_lite_facebook_url',array(
		'label'	=> __('Add Facebook URL','feminine-style-lite'),
		'section' => 'feminine_style_lite_topbar',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('feminine_style_lite_twitter_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('feminine_style_lite_twitter_url',array(
		'label'	=> __('Add Twitter URL','feminine-style-lite'),
		'section' => 'feminine_style_lite_topbar',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('feminine_style_lite_linkedin_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('feminine_style_lite_linkedin_url',array(
		'label'	=> __('Add Linkedin URL','feminine-style-lite'),
		'section' => 'feminine_style_lite_topbar',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('feminine_style_lite_instagram_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('feminine_style_lite_instagram_url',array(
		'label'	=> __('Add Instagram URL','feminine-style-lite'),
		'section' => 'feminine_style_lite_topbar',
		'type'	=> 'text'
	));

	//Header
	$wp_customize->add_section('feminine_style_lite_header',array(
		'title'	=> __('Header','feminine-style-lite'),
		'priority'	=> null,
		'panel' => 'feminine_style_lite_panel_id',
	));

	//Sticky Header
	$wp_customize->add_setting( 'feminine_style_lite_sticky_header',array(
      	'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ) );
    $wp_customize->add_control('feminine_style_lite_sticky_header',array(
    	'type' => 'checkbox',
        'label' => __( 'Sticky Header','feminine-style-lite' ),
        'section' => 'feminine_style_lite_header'
    ));

    $wp_customize->add_setting('feminine_style_lite_sticky_header_padding', array(
		'default'=> '',
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_sticky_header_padding', array(
		'label'	=> __('Sticky Header Padding','feminine-style-lite'),
		'input_attrs' => array(
            'step' => 1,
			'min'  => 0,
			'max'  => 50,
        ),
		'section'=> 'feminine_style_lite_header',
		'type'=> 'number',
	));

	$wp_customize->add_setting('feminine_style_lite_navigation_case',array(
        'default' => 'capitalize',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control('feminine_style_lite_navigation_case',array(
        'type' => 'select',
        'label' => __('Navigation Case','feminine-style-lite'),
        'section' => 'feminine_style_lite_header',
        'choices' => array(
            'uppercase' => __('Uppercase','feminine-style-lite'),
            'capitalize' => __('Capitalize','feminine-style-lite'),
        ),
	) );

	$wp_customize->add_setting( 'feminine_style_lite_nav_font_size', array(
		'default'           => 15,
		'sanitize_callback' => 'feminine_style_lite_sanitize_float',
	) );
	$wp_customize->add_control( 'feminine_style_lite_nav_font_size', array(
		'label' => __( 'Navigation Font Size','feminine-style-lite' ),
		'section'     => 'feminine_style_lite_header',
		'type'        => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 50,
		),
	) );

	$wp_customize->add_setting('feminine_style_lite_font_weight_menu_option',array(
        'default' => '400',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
    ));
    $wp_customize->add_control('feminine_style_lite_font_weight_menu_option',array(
        'type' => 'select',
        'label' => __('Navigation Font Weight','feminine-style-lite'),
        'section' => 'feminine_style_lite_header',
        'choices' => array(
            '100' => __('100','feminine-style-lite'),
            '200' => __('200','feminine-style-lite'),
            '300' => __('300','feminine-style-lite'),
            '400' => __('400','feminine-style-lite'),
            '500' => __('500','feminine-style-lite'),
            '600' => __('600','feminine-style-lite'),
            '700' => __('700','feminine-style-lite'),
            '800' => __('800','feminine-style-lite'),
            '900' => __('900','feminine-style-lite'),
        ),
	) );

	// Preloader
	$wp_customize->add_setting( 'feminine_style_lite_preloader_hide',array(
		'default' => false,
      	'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ) );
    $wp_customize->add_control('feminine_style_lite_preloader_hide',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Preloader','feminine-style-lite' ),
        'section' => 'feminine_style_lite_header'
    ));

    $wp_customize->add_setting('feminine_style_lite_preloader_type',array(
        'default'   => 'center-square',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control( 'feminine_style_lite_preloader_type', array(
		'label' => __( 'Preloader Type','feminine-style-lite' ),
		'section' => 'feminine_style_lite_header',
		'type'  => 'select',
		'settings' => 'feminine_style_lite_preloader_type',
		'choices' => array(
		    'center-square' => __('Center Square','feminine-style-lite'),
		    'chasing-square' => __('Chasing Square','feminine-style-lite'),
	    ),
	));

	$wp_customize->add_setting( 'feminine_style_lite_preloader_color', array(
	    'default' => '#333333',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_preloader_color', array(
  		'label' => 'Preloader Color',
	    'section' => 'feminine_style_lite_header',
	    'settings' => 'feminine_style_lite_preloader_color',
  	)));

  	$wp_customize->add_setting( 'feminine_style_lite_preloader_bg_color', array(
	    'default' => '#fff',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'feminine_style_lite_preloader_bg_color', array(
  		'label' => 'Preloader Background Color',
	    'section' => 'feminine_style_lite_header',
	    'settings' => 'feminine_style_lite_preloader_bg_color',
  	)));

	//home page slider
	$wp_customize->add_section( 'feminine_style_lite_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'feminine-style-lite' ),
		'priority'   => null,
		'panel' => 'feminine_style_lite_panel_id'
	) );

	$wp_customize->selective_refresh->add_partial(
		'feminine_style_lite_slider_hide_show',
		array(
			'selector'        => '#slider .inner_carousel h1',
			'render_callback' => 'feminine_style_lite_customize_partial_feminine_style_lite_slider_hide_show',
		)
	);

	$wp_customize->add_setting('feminine_style_lite_slider_hide_show',array(
       'default' => false,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
	));
	$wp_customize->add_control('feminine_style_lite_slider_hide_show',array(
	   'type' => 'checkbox',
	   'label' => __('Show / Hide slider','feminine-style-lite'),
	   'section' => 'feminine_style_lite_slidersettings',
	));

	$wp_customize->add_setting('feminine_style_lite_slider_background_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'feminine_style_lite_slider_background_img',array(
        'label' => __('Slider Background Image','feminine-style-lite'),
        'description' => __('Image Size 1200px x 550px','feminine-style-lite'),
        'section' => 'feminine_style_lite_slidersettings'
	)));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'feminine_style_lite_slider_page' . $count, array(
			'default'  => '',
			'sanitize_callback' => 'feminine_style_lite_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'feminine_style_lite_slider_page' . $count, array(
			'label' => __( 'Select Slide Image Page', 'feminine-style-lite' ),
			'section' => 'feminine_style_lite_slidersettings',
			'type'    => 'dropdown-pages'
		) );
	}

	//About Section
	$wp_customize->add_section('feminine_style_lite_about_section',array(
		'title'	=> __('About Section','feminine-style-lite'),
		'panel' => 'feminine_style_lite_panel_id',
	));

	$wp_customize->add_setting('feminine_style_lite_small_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('feminine_style_lite_small_title',array(
		'label'	=> esc_html__('Section Small Title','feminine-style-lite'),
		'section'=> 'feminine_style_lite_about_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'feminine_style_lite_about_page', array(
		'default'           => '',
		'sanitize_callback' => 'feminine_style_lite_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'feminine_style_lite_about_page', array(
		'label'   => __( 'Select About Page', 'feminine-style-lite' ),
		'section' => 'feminine_style_lite_about_section',
		'type'    => 'dropdown-pages'
	) );

	$categories = get_categories();
	$cat_posts = array();
	$i = 0;
	$cat_posts[]='Select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('feminine_style_lite_service_category',array(
		'default' => 'select',
		'sanitize_callback' => 'feminine_style_lite_sanitize_choices',
	));
	$wp_customize->add_control('feminine_style_lite_service_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Service Category','feminine-style-lite'),
		'section' => 'feminine_style_lite_about_section',
	));

	//Blog Post
	$wp_customize->add_section('feminine_style_lite_blog_post',array(
		'title'	=> __('Post Settings','feminine-style-lite'),
		'panel' => 'feminine_style_lite_panel_id',
	));	

	$wp_customize->add_setting('feminine_style_lite_date_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_date_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Date','feminine-style-lite'),
       'section' => 'feminine_style_lite_blog_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_author_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_author_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Author','feminine-style-lite'),
       'section' => 'feminine_style_lite_blog_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_comment_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_comment_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Comments','feminine-style-lite'),
       'section' => 'feminine_style_lite_blog_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_time_hide',array(
       'default' => false,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_time_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Time','feminine-style-lite'),
       'section' => 'feminine_style_lite_blog_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_feature_image_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_feature_image_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Featured Image','feminine-style-lite'),
       'section' => 'feminine_style_lite_blog_post'
    ));

    $wp_customize->add_setting( 'feminine_style_lite_featured_image_border_radius', array(
		'default' => 0,
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	) );
	$wp_customize->add_control( 'feminine_style_lite_featured_image_border_radius', array(
		'label' => __( 'Featured image border radius','feminine-style-lite' ),
		'section' => 'feminine_style_lite_blog_post',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min'  => 0,
			'max'  => 50,
		),
	) );

    $wp_customize->add_setting( 'feminine_style_lite_featured_image_box_shadow', array(
		'default' => 0,
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	) );
	$wp_customize->add_control( 'feminine_style_lite_featured_image_box_shadow', array(
		'label' => __( 'Featured image box shadow','feminine-style-lite' ),
		'section' => 'feminine_style_lite_blog_post',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min'  => 0,
			'max'  => 50,
		),
	) );

    $wp_customize->add_setting('feminine_style_lite_post_content',array(
    	'default' => 'Excerpt Content',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control('feminine_style_lite_post_content',array(
        'type' => 'radio',
        'label' => __('Post Content Type','feminine-style-lite'),
        'section' => 'feminine_style_lite_blog_post',
        'choices' => array(
            'No Content' => __('No Content','feminine-style-lite'),
            'Full Content' => __('Full Content','feminine-style-lite'),
            'Excerpt Content' => __('Excerpt Content','feminine-style-lite'),
        ),
	) );

    $wp_customize->add_setting( 'feminine_style_lite_post_excerpt_length', array(
		'default'              => 20,
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	) );
	$wp_customize->add_control( 'feminine_style_lite_post_excerpt_length', array(
		'label' => esc_html__( 'Post Excerpt Length','feminine-style-lite' ),
		'section'  => 'feminine_style_lite_blog_post',
		'type'  => 'number',
		'settings' => 'feminine_style_lite_post_excerpt_length',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'feminine_style_lite_button_excerpt_suffix', array(
		'default'   => __('[...]','feminine-style-lite' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'feminine_style_lite_button_excerpt_suffix', array(
		'label'       => esc_html__( 'Excerpt Suffix','feminine-style-lite' ),
		'section'     => 'feminine_style_lite_blog_post',
		'type'        => 'text',
		'settings' => 'feminine_style_lite_button_excerpt_suffix'
	) );

	$wp_customize->add_setting( 'feminine_style_lite_post_button_text', array(
		'default'   => esc_html__('READ MORE','feminine-style-lite' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'feminine_style_lite_post_button_text', array(
		'label' => esc_html__('Post Button Text','feminine-style-lite' ),
		'section'     => 'feminine_style_lite_blog_post',
		'type'        => 'text',
		'settings'    => 'feminine_style_lite_post_button_text'
	) );

	$wp_customize->add_setting('feminine_style_lite_top_button_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_top_button_padding',array(
		'label'	=> __('Top Bottom Button Padding','feminine-style-lite'),
		'input_attrs' => array(
            'step' => 1,
			'min'  => 0,
			'max'  => 50,
        ),
		'section'=> 'feminine_style_lite_blog_post',
		'type'=> 'number',
	));

	$wp_customize->add_setting('feminine_style_lite_left_button_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_left_button_padding',array(
		'label'	=> __('Left Right Button Padding','feminine-style-lite'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'feminine_style_lite_blog_post',
		'type'=> 'number',
	));

	$wp_customize->add_setting( 'feminine_style_lite_button_border_radius', array(
		'default'=> '0',
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	) );
	$wp_customize->add_control('feminine_style_lite_button_border_radius', array(
        'label'  => __('Button Border Radius','feminine-style-lite'),
        'type'=> 'number',
        'section'  => 'feminine_style_lite_blog_post',
        'input_attrs' => array(
        	'step' => 1,
            'min' => 0,
            'max' => 50,
        ),
    ));

    $wp_customize->add_setting( 'feminine_style_lite_post_blocks', array(
        'default'			=> 'Without box',
        'sanitize_callback'	=> 'feminine_style_lite_sanitize_choices'
    ));
    $wp_customize->add_control( 'feminine_style_lite_post_blocks', array(
        'section' => 'feminine_style_lite_blog_post',
        'type' => 'select',
        'label' => __( 'Post blocks', 'feminine-style-lite' ),
        'choices' => array(
            'Within box'  => __( 'Within box', 'feminine-style-lite' ),
            'Without box' => __( 'Without box', 'feminine-style-lite' ),
    )));

    $wp_customize->add_setting('feminine_style_lite_navigation_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_navigation_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Navigation','feminine-style-lite'),
       'section' => 'feminine_style_lite_blog_post'
    ));

    $wp_customize->add_setting( 'feminine_style_lite_post_navigation_type', array(
        'default'			=> 'numbers',
        'sanitize_callback'	=> 'feminine_style_lite_sanitize_choices'
    ));
    $wp_customize->add_control( 'feminine_style_lite_post_navigation_type', array(
        'section' => 'feminine_style_lite_blog_post',
        'type' => 'select',
        'label' => __( 'Post Navigation Type', 'feminine-style-lite' ),
        'choices' => array(
            'numbers'  => __( 'Number', 'feminine-style-lite' ),
            'next-prev' => __( 'Next/Prev Button', 'feminine-style-lite' ),
    )));

    $wp_customize->add_setting( 'feminine_style_lite_post_navigation_position', array(
        'default'			=> 'bottom',
        'sanitize_callback'	=> 'feminine_style_lite_sanitize_choices'
    ));
    $wp_customize->add_control( 'feminine_style_lite_post_navigation_position', array(
        'section' => 'feminine_style_lite_blog_post',
        'type' => 'select',
        'label' => __( 'Post Navigation Position', 'feminine-style-lite' ),
        'choices' => array(
            'top'  => __( 'Top', 'feminine-style-lite' ),
            'bottom' => __( 'Bottom', 'feminine-style-lite' ),
            'both' => __( 'Both', 'feminine-style-lite' ),
    )));

    //Single Post Settings
	$wp_customize->add_section('feminine_style_lite_single_post',array(
		'title'	=> __('Single Post Settings','feminine-style-lite'),
		'panel' => 'feminine_style_lite_panel_id',
	));	

	$wp_customize->add_setting('feminine_style_lite_feature_image',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_feature_image',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Feature Image','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_tags',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_tags',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Tags','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_comment',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_comment',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Comment','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting( 'feminine_style_lite_comment_width', array(
		'default' => 100,
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	) );
	$wp_customize->add_control( 'feminine_style_lite_comment_width', array(
		'label' => __( 'Comment Textarea Width', 'feminine-style-lite'),
		'section' => 'feminine_style_lite_single_post',
		'type' => 'number',
		'settings' => 'feminine_style_lite_comment_width',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 100,
		),
	) );

    $wp_customize->add_setting('feminine_style_lite_comment_title',array(
       'default' => __('Leave a Reply','feminine-style-lite'),
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_comment_title',array(
       'type' => 'text',
       'label' => __('Comment form Title','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_comment_submit_text',array(
       'default' => __('Post Comment','feminine-style-lite'),
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_comment_submit_text',array(
       'type' => 'text',
       'label' => __('Comment Button Text','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_nav_links',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_nav_links',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Nav Links','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_prev_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_prev_text',array(
       'type' => 'text',
       'label' => __('Previous Navigation Text','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_next_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_next_text',array(
       'type' => 'text',
       'label' => __('Next Navigation Text','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_related_posts',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_related_posts',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Related Posts','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting('feminine_style_lite_related_posts_title',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_related_posts_title',array(
       'type' => 'text',
       'label' => __('Related Posts Title','feminine-style-lite'),
       'section' => 'feminine_style_lite_single_post'
    ));

    $wp_customize->add_setting( 'feminine_style_lite_related_post_count', array(
		'default' => 3,
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	) );
	$wp_customize->add_control( 'feminine_style_lite_related_post_count', array(
		'label' => esc_html__( 'Related Posts Count','feminine-style-lite' ),
		'section' => 'feminine_style_lite_single_post',
		'type' => 'number',
		'settings' => 'feminine_style_lite_related_post_count',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 6,
		),
	) );

    $wp_customize->add_setting( 'feminine_style_lite_post_order', array(
        'default' => 'categories',
        'sanitize_callback'	=> 'feminine_style_lite_sanitize_choices'
    ));
    $wp_customize->add_control( 'feminine_style_lite_post_order', array(
        'section' => 'feminine_style_lite_single_post',
        'type' => 'radio',
        'label' => __( 'Related Posts Order By', 'feminine-style-lite' ),
        'choices' => array(
            'categories' => __('Categories', 'feminine-style-lite'),
            'tags' => __( 'Tags', 'feminine-style-lite' ),
    )));

    //404 page settings
	$wp_customize->add_section('feminine_style_lite_404_page',array(
		'title'	=> __('404 & No Result Page Settings','feminine-style-lite'),
		'priority'	=> null,
		'panel' => 'feminine_style_lite_panel_id',
	));

	$wp_customize->add_setting('feminine_style_lite_404_title',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_404_title',array(
       'type' => 'text',
       'label' => __('404 Page Title','feminine-style-lite'),
       'section' => 'feminine_style_lite_404_page'
    ));

    $wp_customize->add_setting('feminine_style_lite_404_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_404_text',array(
       'type' => 'text',
       'label' => __('404 Page Text','feminine-style-lite'),
       'section' => 'feminine_style_lite_404_page'
    ));

    $wp_customize->add_setting('feminine_style_lite_404_button_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_404_button_text',array(
       'type' => 'text',
       'label' => __('404 Page Button Text','feminine-style-lite'),
       'section' => 'feminine_style_lite_404_page'
    ));

    $wp_customize->add_setting('feminine_style_lite_no_result_title',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_no_result_title',array(
       'type' => 'text',
       'label' => __('No Result Page Title','feminine-style-lite'),
       'section' => 'feminine_style_lite_404_page'
    ));

    $wp_customize->add_setting('feminine_style_lite_no_result_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('feminine_style_lite_no_result_text',array(
       'type' => 'text',
       'label' => __('No Result Page Text','feminine-style-lite'),
       'section' => 'feminine_style_lite_404_page'
    ));

    $wp_customize->add_setting('feminine_style_lite_show_search_form',array(
        'default' => true,
        'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
	));
	$wp_customize->add_control('feminine_style_lite_show_search_form',array(
     	'type' => 'checkbox',
      	'label' => __('Show/Hide Search Form','feminine-style-lite'),
      	'section' => 'feminine_style_lite_404_page',
	));

	//Footer
	$wp_customize->add_section('feminine_style_lite_footer_section',array(
		'title'	=> __('Footer Section','feminine-style-lite'),
		'priority'	=> null,
		'panel' => 'feminine_style_lite_panel_id',
	));

	$wp_customize->selective_refresh->add_partial(
		'feminine_style_lite_show_back_to_top',
		array(
			'selector'        => '.scrollup',
			'render_callback' => 'feminine_style_lite_customize_partial_feminine_style_lite_show_back_to_top',
		)
	);

	$wp_customize->add_setting('feminine_style_lite_show_back_to_top',array(
        'default' => 'true',
        'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
	));
	$wp_customize->add_control('feminine_style_lite_show_back_to_top',array(
     	'type' => 'checkbox',
      	'label' => __('Show/Hide Back to Top Button','feminine-style-lite'),
      	'section' => 'feminine_style_lite_footer_section',
	));

	$wp_customize->add_setting('feminine_style_lite_back_to_top_icon',array(
		'default'	=> 'fas fa-arrow-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Feminine_Style_Lite_Icon_Changer(
        $wp_customize, 'feminine_style_lite_back_to_top_icon',array(
		'label'	=> __('Back to Top Icon','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_footer_section',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('feminine_style_lite_back_to_top_text',array(
		'default'	=> __('Back to Top','feminine-style-lite'),
		'sanitize_callback'	=> 'sanitize_text_field',
	));	
	$wp_customize->add_control('feminine_style_lite_back_to_top_text',array(
		'label'	=> __('Back to Top Button Text','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_footer_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('feminine_style_lite_back_to_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control('feminine_style_lite_back_to_top_alignment',array(
        'type' => 'select',
        'label' => __('Back to Top Button Alignment','feminine-style-lite'),
        'section' => 'feminine_style_lite_footer_section',
        'choices' => array(
            'Left' => __('Left','feminine-style-lite'),
            'Right' => __('Right','feminine-style-lite'),
            'Center' => __('Center','feminine-style-lite'),
        ),
	) );

	$wp_customize->add_setting('feminine_style_lite_footer_background_color', array(
		'default'           => '#000',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'feminine_style_lite_footer_background_color', array(
		'label'    => __('Footer Background Color', 'feminine-style-lite'),
		'section'  => 'feminine_style_lite_footer_section',
	)));

	$wp_customize->add_setting('feminine_style_lite_footer_background_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'feminine_style_lite_footer_background_img',array(
        'label' => __('Footer Background Image','feminine-style-lite'),
        'section' => 'feminine_style_lite_footer_section'
	)));

	$wp_customize->add_setting('feminine_style_lite_footer_widget_layout',array(
        'default'           => '4',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices',
    ));
    $wp_customize->add_control('feminine_style_lite_footer_widget_layout',array(
        'type' => 'radio',
        'label'  => __('Footer widget layout', 'feminine-style-lite'),
        'section'     => 'feminine_style_lite_footer_section',
        'description' => __('Select the number of widget areas you want in the footer. After that, go to Appearance > Widgets and add your widgets.', 'feminine-style-lite'),
        'choices' => array(
            '1'     => __('One', 'feminine-style-lite'),
            '2'     => __('Two', 'feminine-style-lite'),
            '3'     => __('Three', 'feminine-style-lite'),
            '4'     => __('Four', 'feminine-style-lite')
        ),
    ));

    $wp_customize->add_setting('feminine_style_lite_copyright_alignment',array(
        'default' => 'Center',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control('feminine_style_lite_copyright_alignment',array(
        'type' => 'select',
        'label' => __('Copyright Alignment','feminine-style-lite'),
        'section' => 'feminine_style_lite_footer_section',
        'choices' => array(
            'Left' => __('Left','feminine-style-lite'),
            'Right' => __('Right','feminine-style-lite'),
            'Center' => __('Center','feminine-style-lite'),
        ),
	) );

	$wp_customize->add_setting('feminine_style_lite_copyright_fontsize',array(
		'default'	=> 16,
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float',
	));	
	$wp_customize->add_control('feminine_style_lite_copyright_fontsize',array(
		'label'	=> __('Copyright Font Size','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_footer_section',
		'type'		=> 'number'
	));

	$wp_customize->add_setting('feminine_style_lite_copyright_top_bottom_padding',array(
		'default'	=> 15,
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float',
	));	
	$wp_customize->add_control('feminine_style_lite_copyright_top_bottom_padding',array(
		'label'	=> __('Copyright Top Bottom Padding','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_footer_section',
		'type'		=> 'number'
	));

    $wp_customize->selective_refresh->add_partial(
		'feminine_style_lite_footer_copy',
		array(
			'selector'        => '#footer p',
			'render_callback' => 'feminine_style_lite_customize_partial_feminine_style_lite_footer_copy',
		)
	);
	
	$wp_customize->add_setting('feminine_style_lite_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));	
	$wp_customize->add_control('feminine_style_lite_footer_copy',array(
		'label'	=> __('Copyright Text','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_footer_section',
		'type'		=> 'text'
	));

	//Mobile Media Section
	$wp_customize->add_section( 'feminine_style_lite_mobile_media_options' , array(
    	'title'      => __( 'Mobile Media Options', 'feminine-style-lite' ),
		'priority'   => null,
		'panel' => 'feminine_style_lite_panel_id'
	) );

	$wp_customize->add_setting('feminine_style_lite_responsive_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Feminine_Style_Lite_Icon_Changer(
        $wp_customize, 'feminine_style_lite_responsive_open_menu_icon',array(
		'label'	=> __('Open Menu Icon','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_mobile_media_options',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('feminine_style_lite_responsive_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Feminine_Style_Lite_Icon_Changer(
        $wp_customize, 'feminine_style_lite_responsive_close_menu_icon',array(
		'label'	=> __('Close Menu Icon','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_mobile_media_options',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting('feminine_style_lite_responsive_show_back_to_top',array(
        'default' => true,
        'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
	));
	$wp_customize->add_control('feminine_style_lite_responsive_show_back_to_top',array(
     	'type' => 'checkbox',
      	'label' => __('Show / Hide Back to Top Button','feminine-style-lite'),
      	'section' => 'feminine_style_lite_mobile_media_options',
	));

	$wp_customize->add_setting( 'feminine_style_lite_responsive_preloader_hide',array(
		'default' => false,
      	'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ) );
    $wp_customize->add_control('feminine_style_lite_responsive_preloader_hide',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Preloader','feminine-style-lite' ),
        'section' => 'feminine_style_lite_mobile_media_options'
    ));

	//Woocommerce Section
	$wp_customize->add_section( 'feminine_style_lite_woocommerce_options' , array(
    	'title'      => __( 'Additional WooCommerce Options', 'feminine-style-lite' ),
		'priority'   => null,
		'panel' => 'feminine_style_lite_panel_id'
	) );

	// Product Columns
	$wp_customize->add_setting( 'feminine_style_lite_products_per_row' , array(
		'default'           => '3',
		'sanitize_callback' => 'feminine_style_lite_sanitize_choices',
	) );

	$wp_customize->add_control('feminine_style_lite_products_per_row', array(
		'label' => __( 'Product per row', 'feminine-style-lite' ),
		'section'  => 'feminine_style_lite_woocommerce_options',
		'type'     => 'select',
		'choices'  => array(
			'2' => '2',
			'3' => '3',
			'4' => '4',
		),
	) );

	$wp_customize->add_setting('feminine_style_lite_product_per_page',array(
		'default'	=> '9',
		'sanitize_callback'	=> 'feminine_style_lite_sanitize_float'
	));	
	$wp_customize->add_control('feminine_style_lite_product_per_page',array(
		'label'	=> __('Product per page','feminine-style-lite'),
		'section'	=> 'feminine_style_lite_woocommerce_options',
		'type'		=> 'number'
	));

	$wp_customize->add_setting('feminine_style_lite_shop_sidebar',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_shop_sidebar',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Shop page sidebar','feminine-style-lite'),
       'section' => 'feminine_style_lite_woocommerce_options',
    ));

	$wp_customize->add_setting('feminine_style_lite_shop_page_pagination',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_shop_page_pagination',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Shop page pagination','feminine-style-lite'),
       'section' => 'feminine_style_lite_woocommerce_options',
    ));

    $wp_customize->add_setting('feminine_style_lite_product_page_sidebar',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_product_page_sidebar',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Product page sidebar','feminine-style-lite'),
       'section' => 'feminine_style_lite_woocommerce_options',
    ));

    $wp_customize->add_setting('feminine_style_lite_related_product',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_related_product',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Related product','feminine-style-lite'),
       'section' => 'feminine_style_lite_woocommerce_options',
    ));

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_button_padding_top',array(
		'default' => 10,
		'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control( 'feminine_style_lite_woocommerce_button_padding_top',	array(
		'label' => esc_html__( 'Button Top Bottom Padding','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_button_padding_right',array(
	 	'default' => 20,
	 	'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_woocommerce_button_padding_right',	array(
	 	'label' => esc_html__( 'Button Right Left Padding','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
	 	'input_attrs' => array(
			'min' => 0,
			'max' => 50,
	 		'step' => 1,
		),
	));

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_button_border_radius',array(
		'default' => 0,
		'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_woocommerce_button_border_radius',array(
		'label' => esc_html__( 'Button Border Radius','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

    $wp_customize->add_setting('feminine_style_lite_woocommerce_product_border',array(
       'default' => true,
       'sanitize_callback'	=> 'feminine_style_lite_sanitize_checkbox'
    ));
    $wp_customize->add_control('feminine_style_lite_woocommerce_product_border',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable product border','feminine-style-lite'),
       'section' => 'feminine_style_lite_woocommerce_options',
    ));

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_product_padding_top',array(
		'default' => 10,
		'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_woocommerce_product_padding_top', array(
		'label' => esc_html__( 'Product Top Bottom Padding','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_product_padding_right',array(
		'default' => 10,
		'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_woocommerce_product_padding_right', array(
		'label' => esc_html__( 'Product Right Left Padding','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_product_border_radius',array(
		'default' => 0,
		'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_woocommerce_product_border_radius',array(
		'label' => esc_html__( 'Product Border Radius','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_product_box_shadow',array(
		'default' => 0,
		'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control( 'feminine_style_lite_woocommerce_product_box_shadow',array(
		'label' => esc_html__( 'Product Box Shadow','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting('feminine_style_lite_sale_position',array(
        'default' => 'right',
        'sanitize_callback' => 'feminine_style_lite_sanitize_choices'
	));
	$wp_customize->add_control('feminine_style_lite_sale_position',array(
        'type' => 'select',
        'label' => __('Sale badge Position','feminine-style-lite'),
        'section' => 'feminine_style_lite_woocommerce_options',
        'choices' => array(
            'left' => __('Left','feminine-style-lite'),
            'right' => __('Right','feminine-style-lite'),
        ),
	) );

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_sale_top_padding',array(
		'default' => 0,
		'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control( 'feminine_style_lite_woocommerce_sale_top_padding',	array(
		'label' => esc_html__( 'Sale Top Bottom Padding','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_sale_left_padding',array(
	 	'default' => 0,
	 	'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_woocommerce_sale_left_padding',	array(
	 	'label' => esc_html__( 'Sale Right Left Padding','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
	 	'input_attrs' => array(
			'min' => 0,
			'max' => 50,
	 		'step' => 1,
		),
	));

	$wp_customize->add_setting( 'feminine_style_lite_woocommerce_sale_border_radius',array(
		'default' => 0,
		'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_woocommerce_sale_border_radius',array(
		'label' => esc_html__( 'Sale Border Radius','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'feminine_style_lite_product_sale_font_size',array(
		'default' => '',
		'sanitize_callback' => 'feminine_style_lite_sanitize_float'
	));
	$wp_customize->add_control('feminine_style_lite_product_sale_font_size',array(
		'label' => esc_html__( 'Sale Font Size','feminine-style-lite' ),
		'type' => 'number',
		'section' => 'feminine_style_lite_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));
}
add_action( 'customize_register', 'feminine_style_lite_customize_register' );

// logo resize
load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-width.php' );


/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Feminine_Style_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );
		
		// Register custom section types.
		$manager->register_section_type( 'Feminine_Style_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Feminine_Style_Lite_Customize_Section_Pro(
				$manager,
				'feminine_style_lite_example_1',
				array(
					'priority' => 9,
					'title'    => esc_html__( 'Feminine Pro Theme', 'feminine-style-lite' ),
					'pro_text' => esc_html__( 'Go Pro','feminine-style-lite' ),
					'pro_url'  => esc_url( 'https://www.themescaliber.com/themes/feminine-style-wordpress-theme/' ),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'feminine-style-lite-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'feminine-style-lite-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Feminine_Style_Lite_Customize::get_instance();